/*global Drupal, jQuery*/
Drupal.behaviors.euccRocketship = {
  attach: function (context, settings) {
    (function ($) {

      // Init when the popup has opened
      var body = $('body');
      body.once('euccRocketshipOpen').on('eu_cookie_compliance_popup_open', function() {
        $('.eu-cookie-compliance-banner-info').once('euccRocketship').each(function () {
          initCloseEvent();
          initStateLabel();
          initAcceptSelection();
          initAcceptAll();
          initAcceptMinimal();
        });
        // Initiate accessibility for the modal.
        initAccessibility();
      });

      /**
       * Helper function to trigger an event when the popup is closed
       */
      function initCloseEvent() {
        var buttons = $('.eu-cookie-compliance-banner-info button');
        buttons.once('euccRocketshipCloseEvent').click(function (e) {
          $(this).trigger('eu_cookie_compliance_rocketship__popup_close')
          Drupal.attachBehaviors(document.getElementById('sliding-popup'), settings);
        });
      }

      /**
       * Helper function to initialize the state label functionality
       */
      function initStateLabel() {
        var categories = $('.eu-cookie-compliance-category');
        categories.each(function () {
          var category = $(this);
          var check = category.find('input[type="checkbox"]');
          var stateLabel = category.find('.state-label');
          var aria = category.find('.toggle');
          check.change(function () {
            if (check.prop('checked')) {
              stateLabel.addClass('visible');
              aria.attr('aria-checked','true')
            }
            else {
              stateLabel.removeClass('visible');
              aria.attr('aria-checked','false')
            }
          });
        });
      }

      /**
       * Helper function to initialize the dynamic button
       */
      function initAcceptSelection() {
        var dynamicButton = $('.eu-cookie-compliance-rocketship--accept-selection');
        var categoryWrapper = $('.eu-cookie-compliance-categories');
        dynamicButton.click(function (e) {
          e.preventDefault();
          if (dynamicButton.hasClass('open')) {
            $('.eu-cookie-compliance-save-preferences-button').click();
          }
          else {
            dynamicButton.addClass('open');
            dynamicButton.html(dynamicButton.attr('data-selection'));
            categoryWrapper.show();
          }
        });
      }

      /**
       * Helper function to initialize the accept all link.
       */
      function initAcceptAll() {
        var acceptAllLink = $('.eu-cookie-compliance-rocketship--accept-all');
        acceptAllLink.click(function (e) {
          e.preventDefault();
          $('.agree-button.eu-cookie-compliance-default-button').click();
        });
      }

      /**
       * Helper function to initialize the accept minimal link.
       */
      function initAcceptMinimal() {
        var acceptMinimalLink = $('.eu-cookie-compliance-rocketship--accept-minimal');
        var categoryChecks = $('.eu-cookie-compliance-category:not(.disabled) input[type="checkbox"]');
        acceptMinimalLink.click(function (e) {
          e.preventDefault();
          categoryChecks.prop('checked', false);
          $('.eu-cookie-compliance-save-preferences-button').click();
        });
      }

      /**
       * Helper function to initialize accessibility features.
       */
      function initAccessibility() {
        // Elements that should not reachable via sequential keyboard navigation.
        let background = $('body > :not("#sliding-popup")');
        // Elements that should be reachable inside the cookie modal.
        let focusable = $('.eu-cookie-compliance-content').find(' a, .eu-cookie-compliance-category:not(".disabled") .eu-cookie-compliance-category-switch');

        // Hide content from screen readers.
        background.attr('aria-hidden',true);
        // Focus the first focusable element in the modal.
        focusable.first().focus();

        $('.eu-cookie-compliance-rocketship--buttons a').on('click', function(e) {
          // Restore access for screen readers to the main content.
          background.attr('aria-hidden','false');
          // Focus the first link in the main content.
          background.find('a:not(".skip-link")').first().focus();
        });

        // Prevent tabbing on background elements.
        background.find('a, img').on('keydown', function(e) {
          if ($('body').hasClass('eu-cookie-compliance-popup-open')) {
            if (e.keyCode === 9) {
              e.preventDefault();
            }
          }
        });

        // Go back to first focusable item of the modal.
        $('.eu-cookie-compliance-rocketship--dynamic-accept').on('keydown', function (e) {
          if ($("this:focus") && (e.which === 9) && (!e.shiftKey)) {
            e.preventDefault();
            focusable.first().focus();
          }
        });

        // Go to last focusable item of the modal.
        focusable.first().on('keydown',function (e) {
          if ($("this:focus") && (e.which === 9) && (e.shiftKey)) {
            e.preventDefault();
            focusable.last().focus();
          }
        });

        // Let users switch the categories with space.
        let categories = body.find(".eu-cookie-compliance-category");
        categories.each(function(e) {
          let category = $(this);
          // When checkbox is not disabled, you can switch state.
          if (!category.hasClass('disabled')) {
            let toggle = category.find('[role="checkbox"]');
            toggle.keyup(function (e) {
              // When hit spacebar change state.
              if (e.which === 32) {
                let input = category.find('input');
                // Toggle state.
                input.prop('checked',!input.prop("checked"));
                // Change dynamic button state.
                initDynamicButton();
              }
            });
          }
        });
      }
    }(jQuery));
  }
};
